# File: NELakes.R
# Purpose: Example finite GRTS survey designs for Northeast lakes
# Programmers: Tony Olsen and Tom Kincaid
# Date: April 17, 2005
# Last Modified: October 13, 2006

# Load the spsurvey library

library(spsurvey)

# Read the attribute table from the shapefile

att <- read.dbf("reg1_lakes")
cat("The initial six lines in the attribute data frame follow:\n\n")
print(head(att))

# Most column names in the attribute data frame are self-explanatory:
#    LAKRES_ALB_ - unique ID for each lake
#    FTYPE - identifies as lake or reservoir
#    SQ_KM - lake area in sq km
#    X_COORD - Albers projection x-coordinate
#    Y_COORD - Albers projection y-coordinate
#    LEVEL3 - Omernik Level 3 ecoregion
#    LEVEL2 - Omernik Level 2 ecoregion
#    LEVEL1 - Omernik Level 1 ecoregion

# Convert lake area to hectares, print summary information for lake area, and
# provide histograms of lake area

att$area.ha <- att$SQ_KM*100

cat("\nA summary of lake area (hectares) follows:\n\n")
print(summary(att$area.ha))

hist(log10(att$area.ha), breaks=100, main="Histogram of log (Lake Area)",
     xlim=c(-1, 5), xlab="log (Lake Area (ha))")
cat("\n")

# Produce tables for lake type, spatial pattern, and ecoregion

cat("\nA table displaying the number of each lake type follows:\n")
print(table(att$FTYPE))

cat("\nA table displaying the number of lakes for each state follows:\n")
print(table(att$ST))
cat("\n")

cat("\nA table displaying the number of lakes for each Omernik Level 1 ecoregion follows:\n")
print(table(att$LEVEL1))

cat("\nA table displaying the number of lakes for each Omernik Level 2 ecoregion follows:\n")
print(table(att$LEVEL2))

cat("\nA table displaying the number of lakes for each Omernik Level 3 ecoregion follows:\n")
print(table(att$LEVEL3_NAM))
cat("\n")

# Calculate lake area categories

att$lake.area.cat <- cut(att$area.ha, breaks=c(0,1,5,10,50,500,70000),
   include.lowest=TRUE)

cat("\nA summary of lake area categories follows:\n\n")
print(summary(att$lake.area.cat))

#  Four example survey designs follow

# Equal Probability GRTS survey design for all lakes and reservoirs

cat("\nEqual probability GRTS survey design for all lakes and reservoirs\n")

# Create the design list

Equaldsgn <- list(None=list(panel=c(PanelOne=300), seltype="Equal"))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Equalsites <- grts(design=Equaldsgn,
                   DesignID="NELakesEQ",
                   type.frame="finite",
                   src.frame="shapefile",
                   in.shape="reg1_lakes",
                   att.frame=att,
                   prjfilename="reg1_lakes",
                   out.shape="NELakes.EqualSites" )

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Equalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Equalsites))


# Stratified GRTS survey design for all lakes and reservoirs
# Stratify by state

cat("\nStratified GRTS survey design for all lakes and reservoirs\n")

# Create the design list

Stratdsgn <- list(CT=list(panel=c(PanelOne=50), seltype="Equal"),
                  MA=list(panel=c(PanelOne=50), seltype="Equal"),
                  ME=list(panel=c(PanelOne=50), seltype="Equal"),
                  NH=list(panel=c(PanelOne=50), seltype="Equal"),
                  RI=list(panel=c(PanelOne=50), seltype="Equal"),
                  VT=list(panel=c(PanelOne=50), seltype="Equal"))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Stratsites <- grts(design=Stratdsgn,
                   DesignID="NELakesST",
                   type.frame="finite",
                   src.frame="shapefile",
                   in.shape="reg1_lakes",
                   att.frame=att,
                   stratum="ST",
                   prjfilename="reg1_lakes",
                   out.shape="NELakes.StratifySites"
                   )

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Stratsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Stratsites))

# Unequal probability GRTS survey design based on lake area with an oversample

cat("\nUnequal probability GRTS survey design based on lake area with an oversample\n")


# Create the design list

Unequaldsgn <- list(None=list(panel=c(PanelOne=300),
                              seltype="Unequal",
                              caty.n=c("[0,1]"=50, "(1,5]"=50, "(5,10]"=50,
                                       "(10,50]"=50, "(50,500]"=50,
                                       "(500,7e+04]"=50),
                              over=120))

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Unequalsites <- grts(design=Unequaldsgn,
                   DesignID="NELakesUN",
                   type.frame="finite",
                   src.frame="shapefile",
                   in.shape="reg1_lakes",
                   att.frame=att,
                   mdcaty="lake.area.cat",
                   prjfilename="reg1_lakes",
                   out.shape="NELakes.UnEqualSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Unequalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Unequalsites))

# Unequal probability GRTS survey design with an oversample and a panel
# structure for survey over time

cat("\nUnequal probability GRTS survey design with an oversample and a panel structure \nfor survey over time\n")

# Create the design list

Paneldsgn <- list(None=list(panel=c(Annual=50, Year1=50, Year2=50, Year3=50,
                               Year4=50, Year5=50),
                            seltype="Unequal",
                            caty.n=c("[0,1]"=50, "(1,5]"=50, "(5,10]"=50,
                                     "(10,50]"=50, "(50,500]"=50,
                                     "(500,7e+04]"=50),
                            over=120))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Panelsites <- grts(design=Paneldsgn,
                   DesignID="NELakesPan",
                   type.frame="finite",
                   src.frame="shapefile",
                   in.shape="reg1_lakes",
                   att.frame=att,
                   mdcaty="lake.area.cat",
                   prjfilename="reg1_lakes",
                   out.shape="NELakes.PanelSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Panelsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Panelsites))
